@@ -136,7 +136,7 @@ class ChEMBLTargetCofactorProvider(StashableBase):
             if queryTaxId == "-1":
                 logger.info("Skipping target %r (%r)", unpId, chemblIdL)
                 continue
-
+            queryName = chP.getTargetDescription(unpId)
             for chemblId in chemblIdL:
                 if not chaP.hasTargetActivity(chemblId):
                     logger.debug("Skipping target %r (%r)", unpId, chemblId)
@@ -183,6 +183,7 @@ class ChEMBLTargetCofactorProvider(StashableBase):
                         "query_uniprot_id": unpId,
                         "query_id": chemblId,
                         "query_id_type": "ChEMBL",
+                        "query_name": queryName,
                         "provenance_source": provenanceSource,
                         "reference_scheme": refScheme,
                         "assignment_version": assignVersion,
@@ -206,7 +207,8 @@ class ChEMBLTargetCofactorProvider(StashableBase):
         #
         fp = self.__getCofactorDataPath()
         tS = datetime.datetime.now().isoformat()
-        vS = datetime.datetime.now().strftime("%Y-%m-%d")
+        # vS = datetime.datetime.now().strftime("%Y-%m-%d")
+        vS = assignVersion
         ok = self.__mU.doExport(fp, {"version": vS, "created": tS, "cofactors": qD}, fmt="json", indent=3)
         return ok
 
