@@ -28,7 +28,7 @@ class DrugBankTargetCofactorProvider(StashableBase):
     def __init__(self, **kwargs):
         #
         self.__cachePath = kwargs.get("cachePath", ".")
-        self.__dirName = "Drugbank-cofactors"
+        self.__dirName = "DrugBank-cofactors"
         super(DrugBankTargetCofactorProvider, self).__init__(self.__cachePath, [self.__dirName])
         self.__dirPath = os.path.join(self.__cachePath, self.__dirName)
         #
@@ -37,7 +37,7 @@ class DrugBankTargetCofactorProvider(StashableBase):
         #
 
     def testCache(self, minCount=590):
-        logger.info("Drugbank feature count %d", len(self.__fD["cofactors"]) if "cofactors" in self.__fD else 0)
+        logger.info("DrugBank feature count %d", len(self.__fD["cofactors"]) if "cofactors" in self.__fD else 0)
         if self.__fD and "cofactors" in self.__fD and len(self.__fD["cofactors"]) > minCount:
             return True
         else:
@@ -72,11 +72,7 @@ class DrugBankTargetCofactorProvider(StashableBase):
         logger.info("Completed reload (%r) at %s (%.4f seconds)", ok, time.strftime("%Y %m %d %H:%M:%S", time.localtime()), time.time() - startTime)
         return fD
 
-    def buildCofactorList(
-        self,
-        sequenceMatchFilePath,
-        crmpObj=None,
-    ):
+    def buildCofactorList(self, sequenceMatchFilePath, crmpObj=None):
         """Build target cofactor list for the matching entities in the input sequence match file.
 
         Args:
@@ -87,12 +83,12 @@ class DrugBankTargetCofactorProvider(StashableBase):
             bool: True for success or False otherwise
         """
         rDL = []
-        dbP = DrugBankTargetProvider(cachePath=self.__cachePath, useCache=False)
+        dbP = DrugBankTargetProvider(cachePath=self.__cachePath, useCache=True)
         mD = self.__mU.doImport(sequenceMatchFilePath, fmt="json")
         #
-        provenanceSource = "Drugbank"
+        provenanceSource = "DrugBank"
         refScheme = "PDB entity"
-        assignVersion = dbP.getAssignmentVersion()
+        assignVersion = str(dbP.getAssignmentVersion())
         for queryId, matchDL in mD.items():
             unpId = queryId.split("|")[0]
             queryTaxId = queryId.split("|")[2].strip()
@@ -111,20 +107,23 @@ class DrugBankTargetCofactorProvider(StashableBase):
                     cfD = {}
                     cfD["cofactor_id"] = dbD["drugbank_id"]
                     cfD["molecule_name"] = dbD["name"]
-                    cfD["description"] = dbD["description"]
+                    # cfD["description"] = dbD["description"]
                     cfD["moa"] = dbD["moa"]
-                    cfD["pharmacology"] = dbD["pharmacology"]
+                    # cfD["pharmacology"] = dbD["pharmacology"]
                     cfD["inchi_key"] = dbD["inchi_key"]
                     cfD["smiles"] = dbD["smiles"]
                     cfD["pubmed_ids"] = dbD["pubmed_ids"]
                     cfDL.append(self.__addLocalIds(cfD, crmpObj))
                 # --
+                query_name = cfDL[0]["target_name"] if cfDL and "target_name" in cfDL[0] else None
+                # --
                 rD = {
                     "entry_id": entryId,
                     "entity_id": entityId,
                     "query_uniprot_id": unpId,
                     "query_id": unpId,
                     "query_id_type": "DrugBank",
+                    "query_name": query_name,
                     "provenance_source": provenanceSource,
                     "reference_scheme": refScheme,
                     "assignment_version": assignVersion,
@@ -147,7 +146,8 @@ class DrugBankTargetCofactorProvider(StashableBase):
             qD.setdefault(eId, []).append(rD)
         fp = self.__getCofactorDataPath()
         tS = datetime.datetime.now().isoformat()
-        vS = datetime.datetime.now().strftime("%Y-%m-%d")
+        # vS = datetime.datetime.now().strftime("%Y-%m-%d")
+        vS = assignVersion
         ok = self.__mU.doExport(fp, {"version": vS, "created": tS, "cofactors": qD}, fmt="json", indent=3)
         return ok
 
