@@ -132,7 +132,9 @@ class PharosTargetCofactorProvider(StashableBase):
             if not chaP.hasTargetActivity(pharosId):
                 logger.debug("Skipping target %r (%r)", unpId, pharosId)
                 continue
-            #
+            # --
+            description = chaP.getTargetInfo(pharosId, "description")
+            # --
             for matchD in matchDL:
                 tL = matchD["target"].split("|")
                 entryId = tL[0].split("_")[0]
@@ -172,6 +174,7 @@ class PharosTargetCofactorProvider(StashableBase):
                     "query_uniprot_id": unpId,
                     "query_id": pharosId,
                     "query_id_type": "Pharos",
+                    "query_name": description,
                     "provenance_source": provenanceSource,
                     "reference_scheme": refScheme,
                     "assignment_version": assignVersion,
@@ -195,7 +198,8 @@ class PharosTargetCofactorProvider(StashableBase):
         #
         fp = self.__getCofactorDataPath()
         tS = datetime.datetime.now().isoformat()
-        vS = datetime.datetime.now().strftime("%Y-%m-%d")
+        # vS = datetime.datetime.now().strftime("%Y-%m-%d")
+        vS = assignVersion
         ok = self.__mU.doExport(fp, {"version": vS, "created": tS, "cofactors": qD}, fmt="json", indent=3)
         return ok
 
